@@ -6,7 +6,6 @@ from pyppeteer import launch, launcher
 import asyncio
 import nest_asyncio
 from functools import lru_cache
-from atexit import register
 import warnings, re
 from tqdm import tqdm, trange
 from faker import Faker
@@ -111,11 +110,6 @@ def get_source_page(urls: list) -> list:
     return source_pages
 
 
-@register
-def show_now() -> str:
-    print("感谢使用！", datetime.now())
-
-
 def extra(text, type_extra="font", super_mode=False) -> all:
     if type_extra == "own":
         selector = parsel.Selector(text)
@@ -142,6 +136,11 @@ def extra(text, type_extra="font", super_mode=False) -> all:
 
 
 __name__ = ["extra",  "get_window_page", "get_source_page"]
+
+
+
+
+
 """
 The following is a practical example !
 """
