@@ -4,6 +4,8 @@ from tqdm import tqdm, trange
 import csv, openpyxl
 from collections.abc import Iterable
 from threading import Lock
+from zjwbox.boxtools.log_set import LogSet
+from datetime import datetime
 
 
 
@@ -22,6 +24,13 @@ class Store(object):
     text: list or dict
     path: str
     filename:str
+    debug_mode: str = "no"
+    logger: object = LogSet().debug_log(levelname=debug_mode)
+    log: object = LogSet().output_log(levelname="debug")
+    debug: object = logger.warning
+    warn:object = logger.info
+    error:object = logger.debug
+    record:object = log.info
 
     _instance_lock = Lock()
 
@@ -58,6 +67,8 @@ class Store(object):
                     f.writelines(i)
                     count += 1
                     words += len(i)
+                    self.debug(words)
+                    self.record(words)
             print(f"保存完成！location of file：{self.path}/{self.filename}，共{count}行，{words}字！")
         else:
             print("TypeErorr: text must be list !")
@@ -76,21 +87,28 @@ class Store(object):
                     reader = csv.reader(f)
                     for row in reader:
                         print(row)
+                        self.record(row)
             with open(f"{self.path}/{self.filename}", mode=mode, encoding=encode, newline="") as f:
                 writer = csv.writer(f)
                 if isinstance(self.text[0], list):
                     if is_single:
                         for t in tqdm(self.text):
                             writer.writerow(t)
+                            self.debug(t)
+                            self.record(t)
                             tqdm(self.text).set_description("正在写入中！")
                 elif isinstance(self.text, list):
                     if is_single:
                         for t in tqdm(self.text):
                             writer.writerow(t)
+                            self.debug(t)
+                            self.record(t)
                             tqdm(self.text).set_description("正在写入中！")
                     else:
                         for t in tqdm(self.text):
                             writer.writerows(t)
+                            self.debug(t)
+                            self.record(t)
                             tqdm(self.text).set_description("正在写入中！")
                     print("写入完成！")
 
@@ -100,6 +118,7 @@ class Store(object):
                     reader = csv.reader(f)
                     for row in reader:
                         print(row)
+                        self.record(row)
             else:
                 with open(f"{self.path}/{self.filename}", mode=mode, encoding=encode, newline="") as f:
                     Dictwriter = csv.DictWriter(f, headers)
@@ -108,10 +127,14 @@ class Store(object):
                         if is_single:
                             for d in tqdm(self.text):
                                 Dictwriter.writerow(d)
+                                self.debug(d)
+                                self.record(d)
                                 tqdm(self.text).set_description("正在写入中！")
                         else:
                             for d in tqdm(self.text):
                                 Dictwriter.writerows(d)
+                                self.debug(d)
+                                self.record(d)
                                 tqdm(self.text).set_description("正在写入中！")
                         print("写入完成！")
                     else:
@@ -121,6 +144,8 @@ class Store(object):
                         else:
                             for row in tqdm(self.text):
                                 Dictwriter.writerows(row)
+                                self.record(row)
+                                self.debug(row)
                                 tqdm(self.text).set_description("正在写入中！")
                             print("写入完成！")
 
@@ -150,6 +175,8 @@ class Store(object):
             if not isinstance(self.text[0], Iterable):
                 if own:
                     row, column, value = self.text
+                    self.debug(row+"--"+column+"--"+value)
+                    self.record(row+"--"+column+"--"+value)
                     sh.cell(row=row, column=column, value=value)
                     wb.save( f"{self.path}/{self.filename}" )
                     wb.close()
@@ -159,6 +186,8 @@ class Store(object):
                     tqdm_text = tqdm(self.text)
                     for t in tqdm_text:
                         row, column, value = t
+                        self.debug(row+"--"+column+"--"+value)
+                        self.record(row+"--"+column+"--"+value)
                         sh.cell(row=row, column=column, value=value)
                         tqdm_text.set_description("正在保存中！")
                     wb.save( f"{self.path}/{self.filename}" )
@@ -170,11 +199,14 @@ class Store(object):
         sh = wb[sheet_name]
         #按行读取数据转化为列表
         rows_data = list(sh.rows)
-        # print(rows_data)
+        self.record(rows_data)
+        self.debug(rows_data)
         # 获取表单的表头信息
         titles = []
         for title in rows_data[0]:
             titles.append(title.value)
+            self.warn("title.value："+title.value)
+            self.record("title.value："+title.value)
         cases = []
         for case in rows_data[1:]:
             data = []
@@ -182,10 +214,16 @@ class Store(object):
                 data.append(cell.value)
                 if isinstance(cell.value,str):
                     data.append(cell.value)
+                    self.warn("cell.value："+cell.value)
+                    self.record("cell.value："+cell.value)
                 else:
                     data.append(cell.value)
+                    self.warn("cell.value："+cell.value)
+                    self.record("cell.value："+cell.value)
                 case_data = dict(  list (zip(titles,data) )  )
                 cases.append(case_data)
+                self.warn("case_data："+case_data)
+                self.record("case_data："+case_data)
         return cases
 
 
@@ -260,4 +298,3 @@ class Store(object):
                     print(f"错误：{e}")
             return conn
 
-
